============
Pytuneteller
============


.. image:: https://img.shields.io/pypi/v/pytuneteller.svg
        :target: https://pypi.python.org/pypi/pytuneteller

.. image:: https://img.shields.io/travis/yujinyuz/pytuneteller.svg
        :target: https://travis-ci.org/yujinyuz/pytuneteller

.. image:: https://readthedocs.org/projects/pytuneteller/badge/?version=latest
        :target: https://pytuneteller.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/yujinyuz/pytuneteller/shield.svg
     :target: https://pyup.io/repos/github/yujinyuz/pytuneteller/
     :alt: Updates


A python horoscope fortune teller made for fun.


* Free software: MIT license
* Documentation: https://pytuneteller.readthedocs.io.

Summary
-------
It's supposed to tell your fortune for today (or maybe for a specific date).
It should also tell something like "A(n) `<adjective>` or `<verb>` `<noun>` has foreseen your future." or something funny.

For example: ::

    A talking pineapple has foreseen your future: <horoscope goes here>.

Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

